==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/sk/Filter.js <==
({
	"clearFilterDialogTitle": "Zrušiť filter",
	"filterDefDialogTitle": "Filter",
	"ruleTitleTemplate": "Pravidlo ${0}",
	
	"conditionEqual": "rovné",
	"conditionNotEqual": "nerovné",
	"conditionLess": "menšie ako",
	"conditionLessEqual": "menšie ako alebo rovné",
	"conditionLarger": "väčšie ako",
	"conditionLargerEqual": "väčšie ako alebo rovné",
	"conditionContains": "obsahuje",
	"conditionIs": "je",
	"conditionStartsWith": "začína s",
	"conditionEndWith": "končí s",
	"conditionNotContain": "neobsahuje",
	"conditionIsNot": "nie je",
	"conditionNotStartWith": "nezačína s",
	"conditionNotEndWith": "nekončí s",
	"conditionBefore": "pred",
	"conditionAfter": "za",
	"conditionRange": "rozsah",
	"conditionIsEmpty": "je prázdne",
	
	"all": "všetko",
	"any": "žiadne",
	"relationAll": "všetky pravidlá",
	"waiRelAll": "Vyhovovať všetkým týmto pravidlám:",
	"relationAny": "ľubovoľné pravidlá",
	"waiRelAny": "Vyhovovať ľubovoľným z týchto pravidiel:",
	"relationMsgFront": "Vyhovieť",
	"relationMsgTail": "",
	"and": "a",
	"or": "alebo",
	
	"addRuleButton": "Pridať pravidlo",
	"waiAddRuleButton": "Pridať nové pravidlo",
	"removeRuleButton": "Odstrániť pravidlo",
	"waiRemoveRuleButtonTemplate": "Odstrániť pravidlo ${0}",
	
	"cancelButton": "Zrušiť",
	"waiCancelButton": "Zrušiť toto dialógové okno",
	"clearButton": "Zrušiť",
	"waiClearButton": "Zrušiť filter",
	"filterButton": "Filtrovať",
	"waiFilterButton": "Odoslať filter",
	
	"columnSelectLabel": "Stĺpec",
	"waiColumnSelectTemplate": "Stĺpec pre pravidlo ${0}",
	"conditionSelectLabel": "Podmienka",
	"waiConditionSelectTemplate": "Podmienka pre pravidlo ${0}",
	"valueBoxLabel": "Hodnota",
	"waiValueBoxTemplate": "Zadajte hodnotu na filtrovanie pre pravidlo ${0}",
	
	"rangeTo": "do",
	"rangeTemplate": "od ${0} do ${1}",
	
	"statusTipHeaderColumn": "Stĺpec",
	"statusTipHeaderCondition": "Pravidlá",
	"statusTipTitle": "Lišta filtra",
	"statusTipMsg": "Kliknite na lištu filtra, ak chcete filtrovať podľa hodnôt v ${0}.",
	"anycolumn": "ľubovoľný stĺpec",
	"statusTipTitleNoFilter": "Lišta filtra",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelPre": "Vyhovieť",
	"statusTipRelPost": "pravidlá.",
	
	"defaultItemsName": "položky",
	"filterBarMsgHasFilterTemplate": "Zobrazuje sa ${0} z ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Nepoužíva sa žiadny filter",
	
	"filterBarDefButton": "Definovať filter",
	"waiFilterBarDefButton": "Filtrovať tabuľku",
	"a11yFilterBarDefButton": "Filtrovať...",
	"filterBarClearButton": "Zrušiť filter",
	"waiFilterBarClearButton": "Zrušiť filter",
	"closeFilterBarBtn": "Zatvoriť lištu filtra",
	
	"clearFilterMsg": "Toto odstráni filter a zobrazí všetky dostupné záznamy",
	"anyColumnOption": "Ľubovoľný stĺpec",
	
	"trueLabel": "Pravda",
	"falseLabel": "Nepravda"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/sk/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Zrušiť filter",
	"filterDefDialogTitle": "Filter",
	"ruleTitleTemplate": "Pravidlo ${0}",
	
	"conditionEqual": "rovné",
	"conditionNotEqual": "nerovné",
	"conditionLess": "menšie ako",
	"conditionLessEqual": "menšie ako alebo rovné",
	"conditionLarger": "väčšie ako",
	"conditionLargerEqual": "väčšie ako alebo rovné",
	"conditionContains": "obsahuje",
	"conditionIs": "je",
	"conditionStartsWith": "začína s",
	"conditionEndWith": "končí s",
	"conditionNotContain": "neobsahuje",
	"conditionIsNot": "nie je",
	"conditionNotStartWith": "nezačína s",
	"conditionNotEndWith": "nekončí s",
	"conditionBefore": "pred",
	"conditionAfter": "za",
	"conditionRange": "rozsah",
	"conditionIsEmpty": "je prázdne",
	
	"all": "všetko",
	"any": "žiadne",
	"relationAll": "všetky pravidlá",
	"waiRelAll": "Vyhovovať všetkým týmto pravidlám:",
	"relationAny": "ľubovoľné pravidlá",
	"waiRelAny": "Vyhovovať ľubovoľným z týchto pravidiel:",
	"relationMsgFront": "Vyhovieť",
	"relationMsgTail": "",
	"and": "a",
	"or": "alebo",
	
	"addRuleButton": "Pridať pravidlo",
	"waiAddRuleButton": "Pridať nové pravidlo",
	"removeRuleButton": "Odstrániť pravidlo",
	"waiRemoveRuleButtonTemplate": "Odstrániť pravidlo ${0}",
	
	"cancelButton": "Zrušiť",
	"waiCancelButton": "Zrušiť toto dialógové okno",
	"clearButton": "Zrušiť",
	"waiClearButton": "Zrušiť filter",
	"filterButton": "Filtrovať",
	"waiFilterButton": "Odoslať filter",
	
	"columnSelectLabel": "Stĺpec",
	"waiColumnSelectTemplate": "Stĺpec pre pravidlo ${0}",
	"conditionSelectLabel": "Podmienka",
	"waiConditionSelectTemplate": "Podmienka pre pravidlo ${0}",
	"valueBoxLabel": "Hodnota",
	"waiValueBoxTemplate": "Zadajte hodnotu na filtrovanie pre pravidlo ${0}",
	
	"rangeTo": "do",
	"rangeTemplate": "od ${0} do ${1}",
	
	"statusTipHeaderColumn": "Stĺpec",
	"statusTipHeaderCondition": "Pravidlá",
	"statusTipTitle": "Lišta filtra",
	"statusTipMsg": "Kliknite na lištu filtra, ak chcete filtrovať podľa hodnôt v ${0}.",
	"anycolumn": "ľubovoľný stĺpec",
	"statusTipTitleNoFilter": "Lišta filtra",
	"statusTipTitleHasFilter": "Filter",
	"statusTipRelAny": "Zhoda s akýmikoľvek pravidlami.",
	"statusTipRelAll": "Zhoda so všetkými pravidlami.",
	
	"defaultItemsName": "položky",
	"filterBarMsgHasFilterTemplate": "Zobrazuje sa ${0} z ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Nepoužíva sa žiadny filter",
	
	"filterBarDefButton": "Definovať filter",
	"waiFilterBarDefButton": "Filtrovať tabuľku",
	"a11yFilterBarDefButton": "Filtrovať...",
	"filterBarClearButton": "Zrušiť filter",
	"waiFilterBarClearButton": "Zrušiť filter",
	"closeFilterBarBtn": "Zatvoriť lištu filtra",
	
	"clearFilterMsg": "Toto odstráni filter a zobrazí všetky dostupné záznamy",
	"anyColumnOption": "Ľubovoľný stĺpec",
	
	"trueLabel": "Pravda",
	"falseLabel": "Nepravda"
})
//end v1.x content
);
